@@ -438,32 +438,16 @@ def edge_factory(
     base_model=models.Model,
 ):
 
-    if isinstance(node_model, str):
-        try:
-            node_model_name = node_model.split(".")[1]
-        except IndexError:
-
-            node_model_name = node_model
-    else:
-        node_model_name = node_model._meta.model_name
-
-
     class Edge(base_model):
 
-        # Get the current model's name for use in related_name
-        qualname = locals()["__qualname__"]
-        model_name = qualname.rsplit('.', 1)[-1].lower()
-        if not model_name.endswith("s"):
-            model_name = model_name + "s"
-
         parent = models.ForeignKey(
             node_model,
-            related_name=f"children_{model_name}",
+            related_name="children_%(class)ss",
             on_delete=models.CASCADE,
         )
         child = models.ForeignKey(
             node_model,
-            related_name=f"parent_{model_name}",
+            related_name="parent_%(class)ss",
             on_delete=models.CASCADE,
         )
 
